=============================
greencard
=============================

.. image:: https://badge.fury.io/py/greencard.png
    :target: http://badge.fury.io/py/greencard
    
.. image:: https://travis-ci.org/Nekroze/greencard.png?branch=master
        :target: https://travis-ci.org/Nekroze/greencard

.. image:: https://pypip.in/d/greencard/badge.png
        :target: https://crate.io/packages/greencard?version=latest

Documentation
-------------

The full documentation is at http://greencard.rtfd.org.

Quickstart
----------

Install greencard::

    pip install greencard

Then you can use the ``greencard`` command line test runner to descover and run
card tests defined as all ``.py`` files in the test directory from where the
runner is executed. For more information see the usage documentation page.

Features
--------

* A custom testing framework and test runner designed specifically for cards.
